Package 'tigerdemos'

Title: Interactive and Graphical Demos for R using the 'tigerfb' Package
Description: Interactive and graphical demos for R using the 'tigerfb' package.
Authors: Mike Cheng [aut, cre, cph]
Maintainer: Mike Cheng <[email protected]>
License: MIT + file LICENSE
Version: 1.0.1
Built: 2026-07-08 10:52:01 UTC
Source: https://github.com/coolbutuseless/tigerdemos

Help Index


Bubble universe

Description

Bubble universe

Usage

bubble_universe(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Easter Egg

Description

Easter Egg

Usage

easter_egg(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Flying toasters

Description

Flying toasters

Usage

flying_toasters(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Draw on a canvas

Description

Draw on a canvas

Usage

line_drawing(...)

Arguments

...

arguments passed to tigerfb::fb_open()

See Also

Other interactive demos: particles(), simple_demo()


Oxygene

Description

Oxygene

Usage

oxygene(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Parallax square

Description

Parallax square

Usage

parallax_squares(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Particle movement

Description

This example shows the simulated movement of particles. This is not really anything physics-based or reality-based, but looks a little bit organic - like single celled creatures roaming around.

Usage

particles(...)

Arguments

...

arguments passed to tigerfb::fb_open()

Details

Particles are drawn towards the mouse position

See Also

Other interactive demos: line_drawing(), simple_demo()


Plasma

Description

Plasma

Usage

plasma(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Raster bars

Description

Raster bars

Usage

raster_bars(...)

Arguments

...

arguments passed to tigerfb::fb_open()


Simple demonstration

Description

This would be a good framework to adapt when creating your own demo.

Usage

simple_demo(...)

Arguments

...

arguments passed to tigerfb::fb_open()

See Also

Other interactive demos: line_drawing(), particles()