| Title: | Interactive and Graphical Demos for R using the 'tigerfb' Package |
|---|---|
| Description: | Interactive and graphical demos for R using the 'tigerfb' package. |
| Authors: | Mike Cheng [aut, cre, cph] |
| Maintainer: | Mike Cheng <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.1 |
| Built: | 2026-07-08 10:52:01 UTC |
| Source: | https://github.com/coolbutuseless/tigerdemos |
Bubble universe
bubble_universe(...)bubble_universe(...)
... |
arguments passed to |
Easter Egg
easter_egg(...)easter_egg(...)
... |
arguments passed to |
Flying toasters
flying_toasters(...)flying_toasters(...)
... |
arguments passed to |
Draw on a canvas
line_drawing(...)line_drawing(...)
... |
arguments passed to |
Other interactive demos:
particles(),
simple_demo()
Oxygene
oxygene(...)oxygene(...)
... |
arguments passed to |
Parallax square
parallax_squares(...)parallax_squares(...)
... |
arguments passed to |
This example shows the simulated movement of particles. This is not really anything physics-based or reality-based, but looks a little bit organic - like single celled creatures roaming around.
particles(...)particles(...)
... |
arguments passed to |
Particles are drawn towards the mouse position
Other interactive demos:
line_drawing(),
simple_demo()
Plasma
plasma(...)plasma(...)
... |
arguments passed to |
Raster bars
raster_bars(...)raster_bars(...)
... |
arguments passed to |
This would be a good framework to adapt when creating your own demo.
simple_demo(...)simple_demo(...)
... |
arguments passed to |
Other interactive demos:
line_drawing(),
particles()